@@ -18,6 +18,7 @@ from django.db import connection
 from django.db.models import Q
 from django.db.models import QuerySet
 from django.db.models import Max
+from django.conf import settings
 
 
 def APIResponse(ret, status=200, msg=None):
@@ -28,6 +29,18 @@ def APIResponse(ret, status=200, msg=None):
     return ret
 
 
+# --- 默认分页器参数设置 PAGINATION_SETTINGS
+PAGINATION_SETTINGS = {
+    'page_size': 16,       # 每页16个
+    'page_size_query_param': 'page_size',       # 前端控制每页数量时使用的参数名, 'page_size'
+    'page_query_param': 'p',        # 页码控制参数名"p"
+    'max_page_size': 1000,      # 最大1000页
+}
+
+if hasattr(settings, 'PAGINATION_SETTINGS'):
+    PAGINATION_SETTINGS.update(settings.PAGINATION_SETTINGS)
+
+
 class Pagination(PageNumberPagination):
     """
     * 默认分页器参数设置
@@ -35,12 +48,12 @@ class Pagination(PageNumberPagination):
     - page_size: 每页16个
     - page_size_query_param: 前端控制每页数量时使用的参数名, 'page_size'
     - page_query_param: 页码控制参数名"p"
-    - max_page_size: 最大100页
+    - max_page_size: 最大1000页
     """
-    page_size = 100
-    page_size_query_param = 'page_size'
-    page_query_param = 'p'
-    max_page_size = 1000
+    page_size = int(PAGINATION_SETTINGS.get('page_size'))
+    page_size_query_param = PAGINATION_SETTINGS.get('page_size_query_param', 'page_size')
+    page_query_param = PAGINATION_SETTINGS.get('page_query_param', 'p')
+    max_page_size = int(PAGINATION_SETTINGS.get('max_page_size'))
 
 
 class BaseList(ListModelMixin, RetrieveModelMixin, GenericAPIView):
@@ -55,7 +68,7 @@ class BaseList(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     """
 
     pagination_class = Pagination
-    filter_fields = []
+    filter_fields = []      # 精确检索的过滤字段, 如果过滤条件复杂的话, 建议重写
 
     def get(self, request: Request, *args, **kwargs):
         """
